package com.ruoyi.powerdistribution.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.powerdistribution.domain.PdmReportIllegalWeek;
import com.ruoyi.powerdistribution.service.IPdmReportIllegalWeekService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 违章周统计Controller
 *
 * @author ruoyi
 * @date 2024-11-29
 */
@RestController
@RequestMapping("/power/illegal/week")
public class PdmReportIllegalWeekController extends BaseController
{
    @Autowired
    private IPdmReportIllegalWeekService pdmReportIllegalWeekService;

    /**
     * 查询违章周统计列表
     */
    @PreAuthorize("@ss.hasPermi('system:week:list')")
    @GetMapping("/list")
    public TableDataInfo list(PdmReportIllegalWeek pdmReportIllegalWeek)
    {
        startPage();
        List<PdmReportIllegalWeek> list = pdmReportIllegalWeekService.selectPdmReportIllegalWeekList(pdmReportIllegalWeek);
        return getDataTable(list);
    }

    /**
     * 导出违章周统计列表
     */
    @PreAuthorize("@ss.hasPermi('system:week:export')")
    @Log(title = "违章周统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PdmReportIllegalWeek pdmReportIllegalWeek)
    {
        List<PdmReportIllegalWeek> list = pdmReportIllegalWeekService.selectPdmReportIllegalWeekList(pdmReportIllegalWeek);
        ExcelUtil<PdmReportIllegalWeek> util = new ExcelUtil<PdmReportIllegalWeek>(PdmReportIllegalWeek.class);
        util.exportExcel(response, list, "违章周统计数据");
    }

    /**
     * 获取违章周统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:week:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pdmReportIllegalWeekService.selectPdmReportIllegalWeekById(id));
    }

    /**
     * 新增违章周统计
     */
    @PreAuthorize("@ss.hasPermi('system:week:add')")
    @Log(title = "违章周统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PdmReportIllegalWeek pdmReportIllegalWeek)
    {
        return toAjax(pdmReportIllegalWeekService.insertPdmReportIllegalWeek(pdmReportIllegalWeek));
    }

    /**
     * 修改违章周统计
     */
    @PreAuthorize("@ss.hasPermi('system:week:edit')")
    @Log(title = "违章周统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PdmReportIllegalWeek pdmReportIllegalWeek)
    {
        return toAjax(pdmReportIllegalWeekService.updatePdmReportIllegalWeek(pdmReportIllegalWeek));
    }

    /**
     * 删除违章周统计
     */
    @PreAuthorize("@ss.hasPermi('system:week:remove')")
    @Log(title = "违章周统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pdmReportIllegalWeekService.deletePdmReportIllegalWeekByIds(ids));
    }
}
